---
title: Balance CLI tutorial
sidebar_position: 8
hide_table_of_contents: true
hide_title: true
---

import HTMLLoader from '@site/src/components/HTMLLoader';
import useBaseUrl from '@docusaurus/useBaseUrl';

Link to notebook: [balance_cli_tutorial.ipynb](https://github.com/facebookresearch/balance/blob/main/tutorials/balance_cli_tutorial.ipynb)

<HTMLLoader docFile={useBaseUrl('html/tutorials/balance_cli_tutorial.html')}/>
